Splits the requested path into directory-part and filename-part, while ensuring some security to where it may point to.
extract_cran_path_parts(s)A character vector of length 2, with directory path and filename.
If s was a directory (e.g., "src/contrib", "src/contrib/",
"bin/windows/contrib/4.0", etc.) the second element is "".
Can return NULL if s does not fit the repository directory structure.
The requested path, e.g. src/contrib or
bin/windows/contrib/4.0/my_package_v0.1.0.zip.