Learn R Programming

microCRAN (version 0.9.0-1)

path_is_safe_for_cran: Test if path matches repository directory structure

Description

Tests if the requested resource maps to a safe path in the respository, i.e., that it points to `/src/contrib`, `/bin/windows/contrib` or `/bin/macosx/contrib`, and does not attempt to weasle back out with `..`.

Usage

path_is_safe_for_cran(s)

Value

Logical

Arguments

s

The path to check, typically `req$PATH_INFO` in a request handler.